#
# spec file for package asciinema
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pythons python3
Name:           asciinema
Version:        2.3.0
Release:        1.1
Summary:        Terminal session recorder
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Other
URL:            https://asciinema.org
Source:         https://github.com/asciinema/asciinema/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
BuildArch:      noarch

%description
Record of terminal sessions and sharing them on the web.

%prep
%setup -q

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{python3_sitelib}

install -Dpm644 {man/,%{buildroot}%{_mandir}/man1/}%{name}.1

rm -R %{buildroot}%{_datadir}/doc/%{name}

%files
%license LICENSE
%doc CHANGELOG.md CODE_OF_CONDUCT.md CONTRIBUTING.md README.md
%{_bindir}/%{name}
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-%{version}*
%{_mandir}/man?/%{name}.?%{ext_info}

%changelog
* Mon Aug 28 2023 Andrea Manzini <andrea.manzini@suse.com>
- update to 2.3.0:
  * Added official support for Python 3.11
  * Dropped official support for Python 3.6
  * Implemented markers in rec and play -m commands
  * Added --loop option for looped playback in play command
  * Added --stream and --out-fmt option for customizing output of play command
  * Improved terminal charset detection (thanks @djds)
  * Extended cat command to support multiple files (thanks @Low-power)
  * Improved upload error messages
  * Fixed direct playback from URL
  * Made raw output start with terminal size sequence (\e[8;H;Wt)
  * Prevented recording to stdout when it's a TTY
  * Added target file permission checks to avoid ugly errors
  * Removed named pipe re-opening, which was causing hangs in certain scenarios
  * Improved PTY/TTY data reading - it goes in bigger chunks now (256 kb)
  * Fixed deadlock in PTY writes (thanks @Low-power)
  * Improved input forwarding from stdin
  * Ignored OSC responses in recorded stdin stream
* Fri Jul 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * Added official support for Python 3.8, 3.9, 3.10
  * Dropped official support for Python 3.5
  * Added `--cols` / `--rows` options for overriding size of pseudo-terminal reported to recorded program
  * Improved behaviour of `--append` when output file doesn't exist
  * Keyboard input is now explicitly read from a TTY device in addition to stdin (when stdin != TTY)
  * Recorded program output is now explicitly written to a TTY device instead of stdout
  * Dash char (`-`) can now be passed as output filename to write asciicast to stdout
  * Diagnostic messages are now printed to stderr (without colors when stderr != TTY)
  * Improved robustness of writing asciicast to named pipes
  * Lots of codebase modernizations (many thanks to Davis @djds Schirmer!)
  * Many other internal refactorings
* Mon Oct 18 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.0:
  * Ability to pause/resume terminal capture with `C-\` key
    shortcut
  * Desktop notifications - only for the above pause feature at
    the moment
  * Removed dependency on tput/ncurses (thanks @arp242 / Martin
    Tournoij!)
  * ASCIINEMA_REC env var is back (thanks @landonb / Landon
    Bouma!)
  * Terminal answerbacks (CSI 6 n) in `asciinema cat` are now
    hidden (thanks @djpohly / Devin J. Pohly!)
  * Codeset detection works on HP-UX now (thanks @michael-o /
    Michael Osipov!)
  * Attempt at recording to existing file suggests use of
    `--overwrite` option now
  * Upload for users with very long `$USER` is fixed
  * Added official support for Python 3.8 and 3.9
  * Dropped official support for EOL-ed Python 3.4 and 3.5
  * Internal refactorings
* Wed Apr 17 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Reduce space usage by fdupes
* Sun Jan 13 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.0.2
  * Official support for Python 3.7
  * Recording is now possible on US-ASCII locale
  * Improved Android support
  * Possibility of programatic recording with
    asciinema.record_asciicast function
  * Uses new JSON response format added recently to asciinema-server
  * Tweaked message about how to stop recording
  * Added proper description and other metadata to Python package
* Thu Apr  5 2018 avvissu@yandex.by
- Upadte to 2.0.1:
  * Fixed example in asciicast v2 format doc
  * Replaced deprecated encodestring with encodebytes
  * Fixed location of config dir (mv ~/.asciinema ~/.config/asciinema)
  * Internal refactorings
* Sun Feb 11 2018 avvissu@yandex.by
- Update to 2.0.0:
  * see: /usr/share/doc/packages/asciinema/CHANGELOG
* Tue May  9 2017 avvissu@yandex.by
- Update to 1.4.0:
  * see: /usr/share/doc/packages/asciinema/CHANGELOG
* Wed Jul 13 2016 avvissu@yandex.by
- Upadate to 1.3.0:
  * see: /usr/share/doc/packages/asciinema/CHANGELOG
- Create a new spec file for building RPM on Python.
* Thu Mar 31 2016 avvissu@yandex.by
- Remove static libraries
* Fri Mar  4 2016 avvissu@yandex.ru
- Update to 1.2.0:
  * see: /usr/share/doc/packages/asciinema/CHANGELOG
* Fri Jan 22 2016 avvissu@yandex.ru
- Fix build on openSUSE > 42.1: add golang-packaging
- Disable find-provides function
* Tue Dec  8 2015 avvissu@yandex.ru
- Initial package
